/*
 * Copyright (c) 2009,2010,2013 CNRS/LAAS
 *
 * Permission to use, copy, modify, and distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
#ifndef _RMP440CONST_H
#define _RMP440CONST_H

#define RMP440_TICKS_PERIOD 1
#define RMP440_SEC_PERIOD 0.010

#define RMP440_DIST_TO_CONTROLLED_POINT 0.0

/* Default uncertainties */
#define RMP440_VAR_XX	0.001
#define RMP440_VAR_YY	0.001
#define RMP440_VAR_TT	0.0001
#define RMP440_VAR_QCOEFF	0.05


/* Odometry z correction */
#define RMP440_ZODOCOR_ACCTHRES 0.75 /* acceleration threshold (factor of RMP440_ACCEL_LIN_MAX) to disable z update (m/s2) */
#define RMP440_ZODOCOR_LATENCY  4.0  /* how long it is disabled after last accel above threshold (s) */
#define RMP440_ZODOCOR_AVGPITCHSIZE 5 /* number of pitch samples to average for value to use when update is disabled */
#define RMP440_ZODOCOR_AVGVELSIZE 5 /* number of pitch samples to average for value to use when update is disabled */

/* Control Params */
#define RMP440_KP_LONGIT	2.
#define RMP440_KI_LONGIT	1.

#define RMP440_KP_TRANSV	10.
#define RMP440_KI_TRANSV	6.

#define RMP440_KP_ANG		2.
#define RMP440_KI_ANG		2.

/* gyro asserv params */
#define RMP440_DELAY_GYRO_OMEGA	0.3 /* delay between command and measure, in seconds */
#define RMP440_KP_GYRO_OMEGA	2.0
#define RMP440_KP_GYRO_THETA	10.0
#define RMP440_KI_GYRO_THETA	2.0

/* max errors */
#define RMP440_LONGIT_MAX_GAP	0.5
#define RMP440_TRANSV_MAX_GAP	0.5
#define RMP440_ANG_MAX_GAP	0.5

#define RMP440_LONGIT_ERROR_MAX	0.5
#define RMP440_TRANSV_ERROR_MAX	0.5
#define RMP440_ANG_ERROR_MAX	0.5

#define RMP440_LONGIT_MAX_ERR_SUM	1.0
#define RMP440_TRANSV_MAX_ERR_SUM	1.0
#define RMP440_ANG_MAX_ERR_SUM		1.0


/* joystick */
#define RMP440_JOYSTICK_DEVICE_PATH "/dev/input/js0"
#define RMP440_JOYSTICK_VGAIN	1./(32768.0*32768.0) /* 1 m/s max */
#define RMP440_JOYSTICK_WGAIN	1./(32768.0*32768.0) /* 1 rad/s max */

#endif
